@@ -32,6 +32,10 @@
 
 #include <Libkleo/Classify>
 
+#ifndef Q_OS_WIN
+#include <KIO/CopyJob>
+#include <KIO/Global>
+#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 #include "kleopatra_debug.h"
@@ -60,7 +64,6 @@ class AutoDecryptVerifyFilesController::Private
 public:
     explicit Private(AutoDecryptVerifyFilesController *qq);
 
-    void slotDialogCanceled();
     void schedule();
 
     QString getEmbeddedFileName(const QString &fileName) const;
@@ -89,7 +92,7 @@ public:
     std::shared_ptr<Task> m_runningTask;
     bool m_errorDetected = false;
     DecryptVerifyOperation m_operation = DecryptVerify;
-    DecryptVerifyFilesDialog *m_dialog = nullptr;
+    QPointer<DecryptVerifyFilesDialog> m_dialog;
     std::unique_ptr<QTemporaryDir> m_workDir;
 };
 
@@ -98,11 +101,6 @@ AutoDecryptVerifyFilesController::Private::Private(AutoDecryptVerifyFilesControl
     qRegisterMetaType<VerificationResult>();
 }
 
-void AutoDecryptVerifyFilesController::Private::slotDialogCanceled()
-{
-    qCDebug(KLEOPATRA_LOG);
-}
-
 void AutoDecryptVerifyFilesController::Private::schedule()
 {
     if (!m_runningTask && !m_runnableTasks.empty()) {
@@ -166,11 +164,15 @@ void AutoDecryptVerifyFilesController::Private::exec()
         q->connectTask(i);
     }
     coll->setTasks(m_runnableTasks);
-    m_dialog = new DecryptVerifyFilesDialog(coll);
+    DecryptVerifyFilesDialog dialog{coll};
+    m_dialog = &dialog;
     m_dialog->setOutputLocation(heuristicBaseDirectory(m_passedFiles));
 
     QTimer::singleShot(0, q, SLOT(schedule()));
-    if (m_dialog->exec() == QDialog::Accepted && m_workDir) {
+    const auto result = m_dialog->exec();
+    if (result == QDialog::Rejected) {
+        q->cancel();
+    } else if (result == QDialog::Accepted && m_workDir) {
         // Without workdir there is nothing to move.
         const QDir workdir(m_workDir->path());
         const QDir outDir(m_dialog->outputLocation());
@@ -200,11 +202,27 @@ void AutoDecryptVerifyFilesController::Private::exec()
                     suffix = QStringLiteral("_%1").arg(++i);
                 } while (i < 1000);
 
-                if (!moveDir(inpath, ofi.absoluteFilePath())) {
+                const auto destPath = ofi.absoluteFilePath();
+#ifndef Q_OS_WIN
+                auto job = KIO::moveAs(QUrl::fromLocalFile(inpath), QUrl::fromLocalFile(destPath));
+                qCDebug(KLEOPATRA_LOG) << "Moving" << job->srcUrls().front().toLocalFile() << "to" << job->destUrl().toLocalFile();
+                if (!job->exec()) {
+                    if (job->error() == KIO::ERR_USER_CANCELED) {
+                        break;
+                    }
                     reportError(makeGnuPGError(GPG_ERR_GENERAL),
-                            xi18n("Failed to move <filename>%1</filename> to <filename>%2</filename>.",
-                                  inpath, ofi.absoluteFilePath()));
+                                xi18nc("@info", "<para>Failed to move <filename>%1</filename> to <filename>%2</filename>.</para>"
+                                       "<para><message>%3</message></para>",
+                                       inpath, destPath, job->errorString()));
                 }
+#else
+                // On Windows, KIO::move does not work for folders when crossing partition boundaries
+                if (!moveDir(inpath, destPath)) {
+                     reportError(makeGnuPGError(GPG_ERR_GENERAL),
+                                 xi18nc("@info", "<para>Failed to move <filename>%1</filename> to <filename>%2</filename>.</para>",
+                                        inpath, destPath));
+                }
+#endif
                 continue;
             }
 
@@ -262,8 +280,6 @@ void AutoDecryptVerifyFilesController::Private::exec()
         }
     }
     q->emitDoneOrError();
-    delete m_dialog;
-    m_dialog = nullptr;
 }
 
 QVector<AutoDecryptVerifyFilesController::Private::CryptoFile> AutoDecryptVerifyFilesController::Private::classifyAndSortFiles(const QStringList &files)
@@ -482,7 +498,14 @@ std::vector< std::shared_ptr<Task> > AutoDecryptVerifyFilesController::Private::
                 t->setProtocol(cFile.protocol);
                 if (ad) {
                     t->setExtractArchive(true);
-                    t->setOutputDirectory(m_workDir->path());
+                    t->setInputFile(cFile.fileName);
+                    if (output) {
+                        t->setOutputDirectory(m_workDir->path());
+                    } else {
+                        // make gpgtar extract to a subfolder of the work directory based on the input file name
+                        const auto baseFileName = QFileInfo{ad->stripExtension(cFile.protocol, cFile.baseName)}.fileName();
+                        t->setOutputDirectory(QDir{m_workDir->path()}.filePath(baseFileName));
+                    }
                 }
                 tasks.push_back(t);
             } else {
@@ -498,7 +521,14 @@ std::vector< std::shared_ptr<Task> > AutoDecryptVerifyFilesController::Private::
                 t->setProtocol(cFile.protocol);
                 if (ad) {
                     t->setExtractArchive(true);
-                    t->setOutputDirectory(m_workDir->path());
+                    t->setInputFile(cFile.fileName);
+                    if (output) {
+                        t->setOutputDirectory(m_workDir->path());
+                    } else {
+                        // make gpgtar extract to a subfolder of the work directory based on the input file name
+                        const auto baseFileName = QFileInfo{ad->stripExtension(cFile.protocol, cFile.baseName)}.fileName();
+                        t->setOutputDirectory(QDir{m_workDir->path()}.filePath(baseFileName));
+                    }
                 }
                 cFile.output = output;
                 tasks.push_back(t);
@@ -559,7 +589,7 @@ void AutoDecryptVerifyFilesController::Private::cancelAllTasks()
 
 void AutoDecryptVerifyFilesController::cancel()
 {
-    qCDebug(KLEOPATRA_LOG);
+    qCDebug(KLEOPATRA_LOG) << this << __func__;
     try {
         d->m_errorDetected = true;
         if (d->m_dialog) {
